# Install intake-ESM

intake-ESM can be installed in three ways:

```{eval-rst}

.. tab-set::

    .. tab-item:: pip

        Using the `pip <https://pypi.org/project/pip/>`__ package manager:

        .. code:: bash

            $ python -m pip install intake-esm

    .. tab-item:: conda

        Using the `conda <https://conda.io/>`__ package manager that comes with the
        Anaconda/Miniconda distribution:

        .. code:: bash

            $ conda install intake-esm --channel conda-forge

    .. tab-item:: Development version

        To install a development version from source:

        .. code:: bash

            $ git clone https://github.com/intake/intake-esm
            $ cd intake-esm
            $ python -m pip install -e .
```
